#!/usr/bin/perl -w

use Test::More 'no_plan';

package Catch;

sub TIEHANDLE {
    my($class, $var) = @_;
    return bless { var => $var }, $class;
}

sub PRINT  {
    my($self) = shift;
    ${'main::'.$self->{var}} .= join '', @_;
}

sub OPEN  {}    # XXX Hackery in case the user redirects
sub CLOSE {}    # XXX STDERR/STDOUT.  This is not the behavior we want.

sub READ {}
sub READLINE {}
sub GETC {}
sub BINMODE {}

my $Original_File = 'root/usr/share/perl5/vendor_perl/esmith/FormMagick/Panel/printers.pm';

package main;

# pre-5.8.0's warns aren't caught by a tied STDERR.
$SIG{__WARN__} = sub { $main::_STDERR_ .= join '', @_; };
tie *STDOUT, 'Catch', '_STDOUT_' or die $!;
tie *STDERR, 'Catch', '_STDERR_' or die $!;

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 43 root/usr/share/perl5/vendor_perl/esmith/FormMagick/Panel/printers.pm
use_ok('esmith::FormMagick::Panel::printers');
$FM = esmith::FormMagick::Panel::printers->new();
isa_ok($FM, 'esmith::FormMagick::Panel::printers');
$FM->{testing} = 1; # set test mode
$FM->{cgi} = CGI->new();
truncate("30e-smith-LPRng/accounts",0);


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 69 root/usr/share/perl5/vendor_perl/esmith/FormMagick/Panel/printers.pm
my $fm = esmith::FormMagick::Panel::printers->new();
can_ok('main', 'hostname_or_ip');
can_ok('CGI::FormMagick::Validator', 'ip_number');
isnt(CGI::FormMagick::Validator::ip_number($fm, '1.2.3'), "OK", "ip_number works OK");
like(CGI::FormMagick::Validator::ip_number($fm, '1.2.3'), qr(enough octets), "ip_number works OK");
foreach ("1.2.3.4", "255.255.255.255", "foo.com", "foo.bar.com", "123.foo.xxx"){
    is(hostname_or_ip($fm, $_), "OK", "$_ should be OK");
}
foreach ("1.2.3", "foo bar", "foo;bar;com", " ", undef) {
    isnt(hostname_or_ip($fm, $_), "OK", "$_ should not be OK");
}

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 113 root/usr/share/perl5/vendor_perl/esmith/FormMagick/Panel/printers.pm

$FM->show_printers();
like($_STDOUT_, qr/NO_PRINTERS/, 'show_printers');


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 200 root/usr/share/perl5/vendor_perl/esmith/FormMagick/Panel/printers.pm

$FM->{cgi}->param(-name=>'name', -value=>'testprn');
$FM->{cgi}->param(-name=>'description', -value=>'A test printer');
$FM->{cgi}->param(-name=>'location', -value=>'lp0');
$FM->create_printer();
like($FM->{cgi}->param('status_message'), qr/SUCCESS/, 'create_printer');


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 336 root/usr/share/perl5/vendor_perl/esmith/FormMagick/Panel/printers.pm

$FM->print_hidden_fields();
like($_STDOUT_, qr/name/, 'hidden name field');
like($_STDOUT_, qr/description/, 'hidden description field');
like($_STDOUT_, qr/location/, 'hidden location field');


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 372 root/usr/share/perl5/vendor_perl/esmith/FormMagick/Panel/printers.pm

$FM->{cgi}->param(-name=>'printer', -value=>'testprn');
$FM->show_delete_confirmation();
like($_STDOUT_, qr/ABOUT_TO_REMOVE/, 'show_delete_confirmation');


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 427 root/usr/share/perl5/vendor_perl/esmith/FormMagick/Panel/printers.pm

$FM->{cgi}->param(-name=>'printer', -value=>'testprn');
$FM->delete_printer();
like($FM->{cgi}->param('status_message'), qr/DELETED_SUCCESSFULLY/, 
'delete_printer');


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

